@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 # Version.
-our $VERSION = 0.09;
+our $VERSION = 0.10;
 
 # Constructor.
 sub new {
@@ -173,7 +173,13 @@ Text::DSV - DSV parser and serializer.
 
 =head1 SEE ALSO
 
-L<Text::CSV>.
+=over
+
+=item L<Text::CSV>
+
+comma-separated values manipulator (using XS or PurePerl)
+
+=back
 
 =head1 REPOSITORY
 
@@ -187,10 +193,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © 2011-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.09
+0.10
 
 =cut
